======================
IOT CCM CONFIG BUILDER
======================

A tool to build config files for the IOT CCM SDK project.


Usage
=====

Create a configurations file for an IOT component
-------------------------------------------------

    $ python config_file.py --create

Check if a configurations file is validated by the Schema
---------------------------------------------------------

    $ python config_file.py --check path/to/file.json